==> kvirc_2.1.3.orig.tar.gz: kvirc-2.1.3/src/kvilib/qt/kvi_iconloader_qt.cpp <==
// =============================================================================
//
//      --- kvi_iconloader_qt.cpp ---
//
//   This file is part of the KVIrc IRC client distribution
//   Copyright (C) 1999-2000 Szymon Stefanek (stefanek@tin.it)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// =============================================================================

#include <qiconset.h>
#include <qpixmap.h>

#include "kvi_iconloader_qt.h"

KviIconLoader::KviIconLoader()
{
	// Nothing here
}

KviIconLoader::~KviIconLoader()
{
	// Nothing here
}

// TODO: This definitely needs some more refinement
static const QString g_path = "/usr/share/apps/kvirc/pics/";

QIconSet KviIconLoader::loadIconSet(const QString &icon, bool /* ignored */)
{
	return QIconSet(QPixmap(g_path + icon));
}

QPixmap KviIconLoader::loadIcon(const QString &icon, bool /* ignored */)
{
	return QPixmap(g_path + icon);
}

QPixmap KviIconLoader::loadMimeIcon(const QString &icon, bool /* ignored */)
{
	return QPixmap(g_path + icon);
}

==> kvirc2_2.1.3.orig.tar.gz: kvirc2-2.1.3/src/kvilib/qt/kvi_iconloader_qt.cpp <==
// =============================================================================
//
//      --- kvi_iconloader_qt.cpp ---
//
//   This file is part of the KVIrc IRC client distribution
//   Copyright (C) 1999-2000 Szymon Stefanek (stefanek@tin.it)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// =============================================================================

#include <qiconset.h>
#include <qpixmap.h>

#include "kvi_iconloader_qt.h"

static const QString g_icondir = ICONDIR;

KviIconLoader::KviIconLoader()
{
	// Nothing here
}

KviIconLoader::~KviIconLoader()
{
	// Nothing here
}

QIconSet KviIconLoader::loadIconSet(const QString &icon, bool /* ignored */)
{
	return QIconSet(QPixmap(g_icondir + '/' + icon));
}

QPixmap KviIconLoader::loadIcon(const QString &icon, bool /* ignored */)
{
	return QPixmap(g_icondir + '/' + icon);
}

QPixmap KviIconLoader::loadMimeIcon(const QString &icon, bool /* ignored */)
{
	return QPixmap(g_icondir + '/' + icon);
}
